==> haskell-markdown-unlit-0.6.0-18-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-markdown-unlit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 markdown-unlit
version:              0.6.0
visibility:           public
id:                   markdown-unlit-0.6.0-LROsnofn67961QXIsZ3HVW
key:                  markdown-unlit-0.6.0-LROsnofn67961QXIsZ3HVW
license:              MIT
copyright:            (c) 2012-2021 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
homepage:             https://github.com/sol/markdown-unlit#readme
synopsis:             Literate Haskell support for Markdown
description:
    Documentation is here: <https://github.com/sol/markdown-unlit#readme>

category:             Development
abi:                  93faa5adfdf02bb30b40df00057ffe15
exposed:              True
exposed-modules:      Text.Markdown.Unlit
hidden-modules:       Paths_markdown_unlit
import-dirs:          /usr/lib/ghc-9.4.8/site-local/markdown-unlit-0.6.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/markdown-unlit-0.6.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/markdown-unlit-0.6.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-markdown-unlit
hs-libraries:         HSmarkdown-unlit-0.6.0-LROsnofn67961QXIsZ3HVW
depends:
    base-4.17.2.1 base-compat-0.12.3-H9qTMlLoDHsHlMi1O3x7Rp

haddock-interfaces:
    /usr/share/doc/haskell-markdown-unlit/html/markdown-unlit.haddock

haddock-html:         /usr/share/doc/haskell-markdown-unlit/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-markdown-unlit-0.6.0-19-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-markdown-unlit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 markdown-unlit
version:              0.6.0
visibility:           public
id:                   markdown-unlit-0.6.0-H58UA4cFMvZ2OZBWApMqZp
key:                  markdown-unlit-0.6.0-H58UA4cFMvZ2OZBWApMqZp
license:              MIT
copyright:            (c) 2012-2021 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
homepage:             https://github.com/sol/markdown-unlit#readme
synopsis:             Literate Haskell support for Markdown
description:
    Documentation is here: <https://github.com/sol/markdown-unlit#readme>

category:             Development
abi:                  d41ed24869dfd857f7aa4483d60acb0c
exposed:              True
exposed-modules:      Text.Markdown.Unlit
hidden-modules:       Paths_markdown_unlit
import-dirs:          /usr/lib/ghc-9.4.8/site-local/markdown-unlit-0.6.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/markdown-unlit-0.6.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/markdown-unlit-0.6.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-markdown-unlit
hs-libraries:         HSmarkdown-unlit-0.6.0-H58UA4cFMvZ2OZBWApMqZp
depends:
    base-4.17.2.1 base-compat-0.12.3-H9qTMlLoDHsHlMi1O3x7Rp

haddock-interfaces:
    /usr/share/doc/haskell-markdown-unlit/html/markdown-unlit.haddock

haddock-html:         /usr/share/doc/haskell-markdown-unlit/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
